A named list of 256 colour palettes from RColorBrewer, ggsci, viridis,
rcartocolor, nord, dichromat, pals, colorspace, and UtilsR built-in.
Each element is a character vector of hex colours with a "type"
attribute ("discrete" or "continuous").
A named list of 256 colour palettes from RColorBrewer, ggsci, viridis,
rcartocolor, nord, dichromat, pals, colorspace, and UtilsR built-in.
Each element is a character vector of hex colours with a "type"
attribute ("discrete" or "continuous").